@@ -7,8 +7,9 @@
 /* the iterator main struct */
 typedef struct {
     struct srl_iterator *iter;
-    AV *expr;       // srl_path_t do *NOT* own results
+    AV *expr;       // srl_path_t do *NOT* own expr
     AV *results;    // srl_path_t own results
+    int i_own_iterator;
 } srl_path_t;
 
 srl_path_t * srl_build_path_struct(pTHX_ HV *opt);
